==> igniteui-react-core-16.6.5.tgz: package/ES2015/RadialBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MarkerSeriesDescriptionMetadata } from "./MarkerSeriesDescriptionMetadata";
export class RadialBaseDescriptionMetadata extends Base {
    static b(a) {
        if (RadialBaseDescriptionMetadata.a == null) {
            RadialBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RadialBaseDescriptionMetadata.c(a, RadialBaseDescriptionMetadata.a);
        }
    }
    static c(a, b) {
        MarkerSeriesDescriptionMetadata.c(a, b);
        b.item("AngleAxisRef", "(w:AngleAxis)DataRef::object");
        b.item("ValueAxisRef", "(w:ValueAxis)DataRef::object");
        b.item("ClipSeriesToBounds", "Boolean");
    }
    static d(a) {
        RadialBaseDescriptionMetadata.b(a);
        a.m("RadialBase", RadialBaseDescriptionMetadata.a);
    }
}
RadialBaseDescriptionMetadata.$t = markType(RadialBaseDescriptionMetadata, 'RadialBaseDescriptionMetadata');
RadialBaseDescriptionMetadata.a = null;

==> igniteui-react-core-16.11.4.tgz: package/ES2015/RadialBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MarkerSeriesDescriptionMetadata } from "./MarkerSeriesDescriptionMetadata";
/**
 * @hidden
 */
export class RadialBaseDescriptionMetadata extends Base {
    static b(a) {
        if (RadialBaseDescriptionMetadata.a == null) {
            RadialBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RadialBaseDescriptionMetadata.c(a, RadialBaseDescriptionMetadata.a);
        }
    }
    static c(a, b) {
        MarkerSeriesDescriptionMetadata.c(a, b);
        b.item("AngleAxisRef", "(w:AngleAxis,wf:AngleAxis)DataRef::object");
        b.item("ValueAxisRef", "(w:ValueAxis,wf:ValueAxis)DataRef::object");
        b.item("ClipSeriesToBounds", "Boolean");
    }
    static d(a) {
        RadialBaseDescriptionMetadata.b(a);
        a.m("RadialBase", RadialBaseDescriptionMetadata.a);
    }
}
RadialBaseDescriptionMetadata.$t = markType(RadialBaseDescriptionMetadata, 'RadialBaseDescriptionMetadata');
RadialBaseDescriptionMetadata.a = null;
